@@ -349,7 +349,7 @@ let path_of_type_decl ~path type_decl =
   | Some { ptyp_desc = Ptyp_constr ({ txt = lid }, _) } ->
     begin match lid with
     | Lident _ -> []
-    | Ldot (lid, _) -> Ocaml_common.Longident.flatten lid
+    | Ldot (lid, _) -> Astlib.Longident.flatten lid
     | Lapply _ -> assert false
     end
   | _ -> path
@@ -464,7 +464,7 @@ let free_vars_in_core_type typ =
     | { ptyp_desc = (Ptyp_tuple xs | Ptyp_constr (_, xs)) } ->
       List.map free_in xs |> List.concat
     | { ptyp_desc = Ptyp_alias (x, name) } ->
-      [mkloc name typ.ptyp_loc]
+      [mkloc name.txt typ.ptyp_loc]
       @ free_in x
     | { ptyp_desc = Ptyp_poly (bound, x) } ->
       List.filter (fun y -> not (List.mem y bound)) (free_in x)
@@ -577,7 +577,9 @@ let binop_reduce x a b =
 
 let strong_type_of_type ty =
   let free_vars = free_vars_in_core_type ty in
-  Typ.force_poly @@ Typ.poly free_vars ty
+  match free_vars with
+    | [] -> ty
+    | _ -> Typ.force_poly @@ Typ.poly free_vars ty
 
 type deriver_options =
   | Options of (string * expression) list
@@ -606,13 +608,13 @@ let derive path pstr_loc item attributes fn arg =
           name,
           Options
             (options |> List.map (fun ({ txt }, expr) ->
-               String.concat "." (Ocaml_common.Longident.flatten txt), expr))
+               String.concat "." (Astlib.Longident.flatten txt), expr))
         | { pexp_desc = Pexp_apply ({ pexp_desc = Pexp_ident name }, _) } ->
           name, Unknown_syntax
         | { pexp_loc } ->
           raise_errorf ~loc:pexp_loc "Unrecognized [@@deriving] syntax"
       in
-      let name, loc = String.concat "_" (Ocaml_common.Longident.flatten name.txt), name.loc in
+      let name, loc = String.concat "_" (Astlib.Longident.flatten name.txt), name.loc in
       let is_optional, options =
         match options with
         | Unknown_syntax -> false, options
