@@ -15,19 +15,16 @@ type nonrec 'a lazy_t = 'a lazy_t
 type nonrec bytes = bytes
 
 #if OCAML_VERSION >= (4, 07, 0)
+(* We require 4.08 while 4.07 already has a Stdlib module.
+   In 4.07, the type equalities on Stdlib.Pervasives
+   are not strong enough for the 'include Stdlib'
+   below to satisfy the signature constraints on
+   Ppx_deriving_runtime.Pervasives. *)
 module Stdlib = Stdlib
 
 include Stdlib
 
 module Result = struct
-  (* Type manifest shoud be [('a, 'b) result]:
-     - it can't be [Result.t] because [Result] is not defined in 4.07 std-lib
-       and the result package just exposes [Result.t] as an alias to [result]
-       without re-exporting the constructors
-     - it can't be [Result.result] because the [include Stdlib] above makes
-       [Result] be [Stdlib.Result] (shadowing the [Result] module from the
-       result package), and [Stdlib.Result] does not define [result] (that's
-       why we override the [Result] module as the first place. *)
   type ('a, 'b) t = ('a, 'b) result =
     | Ok of 'a
     | Error of 'b
@@ -61,24 +58,15 @@ module Weak = Weak
 module Printf = Printf
 module Format = Format
 module Buffer = Buffer
-
-include Pervasives
-
 module Result = struct
-  (* the "result" compatibility module defines Result.result as a variant
-     and Result.t as an alias *)
-  type ('a, 'b) t = ('a, 'b) Result.result =
+  type ('a, 'b) t = ('a, 'b) result =
     | Ok of 'a
     | Error of 'b
 
-  (* ... and we also expose Result.result for backward-compatibility *)
-  type ('a, 'b) result = ('a, 'b) Result.result =
+  type nonrec ('a, 'b) result = ('a, 'b) result =
     | Ok of 'a
     | Error of 'b
 end
-#endif
-
-#if OCAML_VERSION < (4, 08, 0)
 module Option = struct
   type 'a t = 'a option
 
@@ -89,7 +77,9 @@ module Option = struct
 
   let to_result ~none o =
     match o with
-    | None -> Result.Error none
-    | Some x -> Result.Ok x
+    | None -> Error none
+    | Some x -> Ok x
 end
+
+include Pervasives
 #endif
